@@ -21,6 +21,7 @@ Development was by Zac Adam-MacEwen. See the README.md for details.
 
 # General Purpose Imports Block
 import json
+import os
 
 
 class SteckerSettingsInvalid(Exception):
@@ -52,18 +53,19 @@ class Stecker(object):
         """Accepts a string of space-seperated letter pairs denoting stecker
          settings, deduplicates them and grants the object its properties.
         """
-        stecker_pairs = setting.upper().split(" ")
-        used_characters = []
-        valid_chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-        self.stecker_setting = {}
-        for pair in stecker_pairs:
-            if (pair[0] in used_characters) or (pair[1] in used_characters):
-                raise SteckerSettingsInvalid
-            elif (pair[0] not in valid_chars) or (pair[1] not in valid_chars):
-                raise SteckerSettingsInvalid
-            else:
-                self.stecker_setting.update({pair[0]: pair[1]})
-                self.stecker_setting.update({pair[1]: pair[0]})
+        if setting is not None:
+            stecker_pairs = setting.upper().split(" ")
+            used_characters = []
+            valid_chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+            self.stecker_setting = {}
+            for pair in stecker_pairs:
+                if (pair[0] in used_characters) or (pair[1] in used_characters):
+                    raise SteckerSettingsInvalid
+                elif (pair[0] not in valid_chars) or (pair[1] not in valid_chars):
+                    raise SteckerSettingsInvalid
+                else:
+                    self.stecker_setting.update({pair[0]: pair[1]})
+                    self.stecker_setting.update({pair[1]: pair[0]})
 
     def steck(self, char):
         """Accepts a character and parses it through the stecker board.
@@ -140,8 +142,10 @@ class Rotor(object):
         else:
             raise RotorNotFound
         if ringstellung is None:
-            ringstellung = "A"
-        ringstellung = alpha_to_num(ringstellung.upper())
+            self.ringstellung = "A"
+        else:
+            self.ringstellung = ringstellung
+        ringstellung = alpha_to_num(self.ringstellung.upper())
 
         # Extremely nasty ringstellung implementation follows.
         # For this to work, ringstellung needs to be a number, rather than an index.
@@ -286,7 +290,9 @@ class Enigma(object):
         # We have to reverse the rotors as we insert them because the signal
         # originates at the right-hand edge of the wheelpack.
         if catalog == "default":
-            with open("catalogue.json", "r") as file:
+            resource_dir = os.path.split(__file__)[0]
+            path_to_default_catalog = os.path.join(resource_dir, "catalogue.json")
+            with open(path_to_default_catalog, "r") as file:
                 catalog = json.load(file)
         wheels = []
         rotors.reverse()
@@ -364,6 +370,15 @@ def alpha_to_num(char):
             }
     return translator[char.upper()]
 
+def num_to_alpha(integ):
+    """takes a numeral value and spits out the corresponding letter."""
+    translator = {
+                1: 'A', 2: 'B', 3: 'C', 4: 'D', 5: 'E', 6: 'F', 7: 'G', 8: 'H',
+                9: 'I', 10: 'J', 11: 'K', 12: 'L', 13: 'M', 14: 'N', 15: 'O',
+                16: 'P', 17: 'Q', 18: 'R', 19: 'S', 20: 'T', 21: 'U', 22: 'V',
+                23: 'W', 24: 'X', 25: 'Y', 26: 'Z'
+                }
+    return translator[integ]
 
 def map_faces(rotor):
     """Are you ready for bad entry pinning mapping?"""
